@@ -4,8 +4,8 @@ from __future__ import absolute_import
 
 # import apis into api package
 from lusid_notifications.api.application_metadata_api import ApplicationMetadataApi
+from lusid_notifications.api.deliveries_api import DeliveriesApi
 from lusid_notifications.api.event_types_api import EventTypesApi
 from lusid_notifications.api.events_api import EventsApi
-from lusid_notifications.api.messages_api import MessagesApi
 from lusid_notifications.api.notifications_api import NotificationsApi
 from lusid_notifications.api.subscriptions_api import SubscriptionsApi
